
# PDF Zip Password Cracker

This package provides tools for cracking password-protected ZIP and PDF files. It can use a word list for dictionary attacks or perform brute-force attacks based on specified character sets and password lengths.

## Run Script


- To install this package, use pip:

        pip install pypdfzipcrack

- To Run This Tool Just Type :

        pdfzipcrack
    
## Features

- Zip Password Cracker:
    - Dictionary attack using a word list file.
    - Brute-force attack with customizable character sets (letters, numbers, special characters).
    - Supports AES encrypted ZIP files.

- PDF Password Cracker:
    - Dictionary attack using a word list file.
    - Brute-force attack with customizable character sets (letters, numbers, special characters).


## 🚀 About Me

Package Creator : Bhavya Padaliya 

I'm a Currently Student And But Interested In Python Development

You Can Also Check My Other Works On My Github Profile : 

[![Github Profile](https://img.shields.io/badge/Github_Profile-000?style=for-the-badge)](https://github.com/neuqs90)

License
-------

This project is licensed under the MIT License. See the [LISENCE.txt](https://github.com/neuqs90/pypdfzipcrack/blob/main/LISENCE.txt) file for more details.

Contributing
------------

Contributions are welcome! Please fork the repository and submit a pull request.

Support
-------

If you have any questions or issues, please open an issue in the GitHub repository.

Acknowledgments
---------------

This package uses the following libraries:

- [pyzipper](https://github.com/danifus/pyzipper.git)
- [PyPDF2](https://pypi.org/project/PyPDF2/)